@@ -36,11 +36,11 @@
 #define _codec MUROAR_CODEC_PCM_S_BE // force because ROAR_CODEC_DEFAULT can be something non-BE, too.
 #endif
 
-static int _return_err (void) {
+static int muroard_cf_ogg_vorbis_private_return_err (void) {
  return -1;
 }
 
-static size_t _read (void *ptr, size_t size, size_t nmemb, void *datasource) {
+static size_t muroard_cf_ogg_vorbis_private_read (void *ptr, size_t size, size_t nmemb, void *datasource) {
  ssize_t r;
 
  r = muroard_stream_network_read(((struct muroard_stream *)datasource)->cf_data.ogg_vorbis.stream_id, ptr, size*nmemb);
@@ -55,10 +55,10 @@ static size_t _read (void *ptr, size_t size, size_t nmemb, void *datasource) {
 }
 
 static const ov_callbacks _callbacks = {
-  .read_func  = _read,
-  .seek_func  = (int    (*)(void *, ogg_int64_t, int      )) _return_err,
-  .close_func = (int    (*)(void *                        )) _return_err,
-  .tell_func  = (long   (*)(void *                        )) _return_err
+  .read_func  = muroard_cf_ogg_vorbis_private_read,
+  .seek_func  = (int    (*)(void *, ogg_int64_t, int      )) muroard_cf_ogg_vorbis_private_return_err,
+  .close_func = (int    (*)(void *                        )) muroard_cf_ogg_vorbis_private_return_err,
+  .tell_func  = (long   (*)(void *                        )) muroard_cf_ogg_vorbis_private_return_err
 };
 
 ssize_t muroard_cf_ogg_vorbis_read(int id, struct muroard_stream * stream, void * buf, size_t len) {
