@@ -30,14 +30,10 @@
 #define DRIVER_HAVE_INIT
 #define DRIVER_USE_SYSIO
 
-static int muroard_driver_esd_fh = -1;
-
-#define DRIVER_SYSIO_FH muroard_driver_esd_fh
-
 int muroard_driver_init(const char * dev) {
  esd_format_t fmt = ESD_PLAY|ESD_STREAM|ESD_BITS16;
 
- switch (muroard_g_sa_channels) {
+ switch (muroard_state_member(sa_channels)) {
   case 1:  fmt |= ESD_MONO;   break;
   case 2:  fmt |= ESD_STEREO; break;
   default:
@@ -45,8 +41,8 @@ int muroard_driver_init(const char * dev) {
    break;
  }
 
- muroard_driver_esd_fh = esd_play_stream_fallback(fmt, muroard_g_sa_rate, dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME);
- if ( muroard_driver_esd_fh == -1 )
+ muroard_state_member(driver_fh) = esd_play_stream_fallback(fmt, muroard_state_member(sa_rate), dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME);
+ if ( muroard_state_member(driver_fh) == -1 )
   return -1;
 
  return 0;
