@@ -657,8 +657,10 @@ int muroard_stream_new_source(const char * filename, int dir, struct muroard_aud
   return -1;
 
  stream = muroard_stream_new(0, dir, info);
- if ( stream == -1 )
+ if ( stream == -1 ) {
+  close(fh);
   return -1;
+ }
 
  if ( muroard_stream_move_client(stream, 0) == -1 ) {
   muroard_stream_delete(stream);
